@@ -14,17 +14,10 @@ use function sprintf;
 /**
  * @internal This class is not covered by the backward compatibility promise for phpunit/php-code-coverage
  */
-final class CrapIndex
+final readonly class CrapIndex
 {
-    /**
-     * @var int
-     */
-    private $cyclomaticComplexity;
-
-    /**
-     * @var float
-     */
-    private $codeCoverage;
+    private int $cyclomaticComplexity;
+    private float $codeCoverage;
 
     public function __construct(int $cyclomaticComplexity, float $codeCoverage)
     {
@@ -44,7 +37,7 @@ final class CrapIndex
 
         return sprintf(
             '%01.2F',
-            $this->cyclomaticComplexity ** 2 * (1 - $this->codeCoverage / 100) ** 3 + $this->cyclomaticComplexity
+            $this->cyclomaticComplexity ** 2 * (1 - $this->codeCoverage / 100) ** 3 + $this->cyclomaticComplexity,
         );
     }
 }
